
tailbone-quickbooks
===================

Rattail is a retail software framework, released under the GNU General
Public License.

This package contains software interfaces for `Quickbooks`_.

.. _`Quickbooks`: https://quickbooks.intuit.com/

Please see the `Rattail Project`_ for more information.

.. _`Rattail Project`: https://rattailproject.org/
